# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AntdSegmentedColoring(Component):
    """An AntdSegmentedColoring component.


Keyword arguments:

- id (string; optional)

- bordered (boolean; default True)

- breakpoints (list of numbers; required)

- className (string | dict; optional)

- colorBlockPosition (a value equal to: 'left', 'right'; default 'right')

- colorBlockStyle (dict; optional)

- colors (list of strings; required)

- controls (boolean; default True)

- disabled (boolean; default False)

- inputNumberStyle (dict; optional)

- key (string; optional)

- keyboard (boolean; default True)

- loading_state (dict; optional)

    `loading_state` is a dict with keys:

    - component_name (string; optional):
        Holds the name of the component that is loading.

    - is_loading (boolean; optional):
        Determines if the component is loading or not.

    - prop_name (string; optional):
        Holds which property is loading.

- max (number; optional)

- min (number; optional)

- placeholder (string; optional)

- precision (number; default 2)

- pureLegend (boolean; default False)

- pureLegendLabelStyle (dict; optional)

- readOnly (boolean; optional)

- size (a value equal to: 'large', 'small', 'middle'; default 'middle')

- step (number; default 0.01)

- style (dict; optional)"""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdSegmentedColoring'
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, className=Component.UNDEFINED, style=Component.UNDEFINED, key=Component.UNDEFINED, breakpoints=Component.REQUIRED, colors=Component.REQUIRED, controls=Component.UNDEFINED, keyboard=Component.UNDEFINED, min=Component.UNDEFINED, max=Component.UNDEFINED, step=Component.UNDEFINED, precision=Component.UNDEFINED, disabled=Component.UNDEFINED, size=Component.UNDEFINED, bordered=Component.UNDEFINED, placeholder=Component.UNDEFINED, readOnly=Component.UNDEFINED, pureLegend=Component.UNDEFINED, inputNumberStyle=Component.UNDEFINED, colorBlockStyle=Component.UNDEFINED, colorBlockPosition=Component.UNDEFINED, pureLegendLabelStyle=Component.UNDEFINED, loading_state=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'bordered', 'breakpoints', 'className', 'colorBlockPosition', 'colorBlockStyle', 'colors', 'controls', 'disabled', 'inputNumberStyle', 'key', 'keyboard', 'loading_state', 'max', 'min', 'placeholder', 'precision', 'pureLegend', 'pureLegendLabelStyle', 'readOnly', 'size', 'step', 'style']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'bordered', 'breakpoints', 'className', 'colorBlockPosition', 'colorBlockStyle', 'colors', 'controls', 'disabled', 'inputNumberStyle', 'key', 'keyboard', 'loading_state', 'max', 'min', 'placeholder', 'precision', 'pureLegend', 'pureLegendLabelStyle', 'readOnly', 'size', 'step', 'style']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        for k in ['breakpoints', 'colors']:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')

        super(AntdSegmentedColoring, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AntdModal(Component):
    """An AntdModal component.


Keyword arguments:

- children (a list of or a singular dash component, string or number; optional)

- id (string; optional)

- bodyStyle (dict; optional)

- cancelButtonProps (dict; optional)

    `cancelButtonProps` is a dict with keys:

    - danger (boolean; optional)

    - disabled (boolean; optional)

    - shape (a value equal to: 'circle', 'round'; optional)

    - size (a value equal to: 'small', 'middle', 'large'; optional)

    - type (a value equal to: 'primary', 'ghost', 'dashed', 'link', 'text', 'default'; optional)

- cancelCounts (number; default 0)

- cancelText (a list of or a singular dash component, string or number; optional)

- centered (boolean; optional)

- className (string; optional)

- closable (boolean; optional)

- closeCounts (number; default 0)

- confirmAutoSpin (boolean; default False)

- confirmLoading (boolean; default False)

- key (string; optional)

- keyboard (boolean; optional)

- loadingOkText (a list of or a singular dash component, string or number; optional)

- loading_state (dict; optional)

    `loading_state` is a dict with keys:

    - component_name (string; optional):
        Holds the name of the component that is loading.

    - is_loading (boolean; optional):
        Determines if the component is loading or not.

    - prop_name (string; optional):
        Holds which property is loading.

- locale (a value equal to: 'zh-cn', 'en-us'; default 'zh-cn')

- mask (boolean; optional)

- maskClosable (boolean; optional)

- maskStyle (dict; optional)

- okButtonProps (dict; optional)

    `okButtonProps` is a dict with keys:

    - danger (boolean; optional)

    - disabled (boolean; optional)

    - shape (a value equal to: 'circle', 'round'; optional)

    - size (a value equal to: 'small', 'middle', 'large'; optional)

    - type (a value equal to: 'primary', 'ghost', 'dashed', 'link', 'text', 'default'; optional)

- okClickClose (boolean; default True)

- okCounts (number; default 0)

- okText (a list of or a singular dash component, string or number; optional)

- renderFooter (boolean; optional)

- style (dict; optional)

- title (a list of or a singular dash component, string or number; optional)

- transitionType (a value equal to: 'none', 'fade', 'zoom', 'zoom-big', 'zoom-big-fast', 'zoom-up', 'zoom-down', 'zoom-left', 'zoom-right', 'slide-up', 'slide-down', 'slide-left', 'slide-right', 'move-up', 'move-down', 'move-left', 'move-right'; default 'zoom')

- visible (boolean; default False)

- width (number | string; optional)

- zIndex (number; optional)"""
    _children_props = ['title', 'okText', 'loadingOkText', 'cancelText']
    _base_nodes = ['title', 'okText', 'loadingOkText', 'cancelText', 'children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdModal'
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, className=Component.UNDEFINED, style=Component.UNDEFINED, key=Component.UNDEFINED, locale=Component.UNDEFINED, title=Component.UNDEFINED, visible=Component.UNDEFINED, okText=Component.UNDEFINED, loadingOkText=Component.UNDEFINED, okButtonProps=Component.UNDEFINED, cancelText=Component.UNDEFINED, cancelButtonProps=Component.UNDEFINED, renderFooter=Component.UNDEFINED, width=Component.UNDEFINED, centered=Component.UNDEFINED, keyboard=Component.UNDEFINED, closable=Component.UNDEFINED, mask=Component.UNDEFINED, maskClosable=Component.UNDEFINED, okClickClose=Component.UNDEFINED, zIndex=Component.UNDEFINED, maskStyle=Component.UNDEFINED, bodyStyle=Component.UNDEFINED, okCounts=Component.UNDEFINED, cancelCounts=Component.UNDEFINED, closeCounts=Component.UNDEFINED, confirmLoading=Component.UNDEFINED, confirmAutoSpin=Component.UNDEFINED, transitionType=Component.UNDEFINED, loading_state=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'bodyStyle', 'cancelButtonProps', 'cancelCounts', 'cancelText', 'centered', 'className', 'closable', 'closeCounts', 'confirmAutoSpin', 'confirmLoading', 'key', 'keyboard', 'loadingOkText', 'loading_state', 'locale', 'mask', 'maskClosable', 'maskStyle', 'okButtonProps', 'okClickClose', 'okCounts', 'okText', 'renderFooter', 'style', 'title', 'transitionType', 'visible', 'width', 'zIndex']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'bodyStyle', 'cancelButtonProps', 'cancelCounts', 'cancelText', 'centered', 'className', 'closable', 'closeCounts', 'confirmAutoSpin', 'confirmLoading', 'key', 'keyboard', 'loadingOkText', 'loading_state', 'locale', 'mask', 'maskClosable', 'maskStyle', 'okButtonProps', 'okClickClose', 'okCounts', 'okText', 'renderFooter', 'style', 'title', 'transitionType', 'visible', 'width', 'zIndex']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AntdModal, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AntdTimeline(Component):
    """An AntdTimeline component.


Keyword arguments:

- id (string; optional)

- className (string | dict; optional)

- items (list of dicts; required)

    `items` is a list of dicts with keys:

    - color (string; optional)

    - content (a list of or a singular dash component, string or number; optional)

    - icon (a list of or a singular dash component, string or number; optional)

    - label (a list of or a singular dash component, string or number; optional)

- key (string; optional)

- loading_state (dict; optional)

    `loading_state` is a dict with keys:

    - component_name (string; optional):
        Holds the name of the component that is loading.

    - is_loading (boolean; optional):
        Determines if the component is loading or not.

    - prop_name (string; optional):
        Holds which property is loading.

- mode (a value equal to: 'left', 'alternate', 'right'; default 'left')

- pending (a list of or a singular dash component, string or number; optional)

- pendingDot (a list of or a singular dash component, string or number; optional)

- reverse (boolean; default False)

- style (dict; optional)"""
    _children_props = ['items[].content', 'items[].icon', 'items[].label', 'pending', 'pendingDot']
    _base_nodes = ['pending', 'pendingDot', 'children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdTimeline'
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, className=Component.UNDEFINED, style=Component.UNDEFINED, key=Component.UNDEFINED, items=Component.REQUIRED, mode=Component.UNDEFINED, pending=Component.UNDEFINED, pendingDot=Component.UNDEFINED, reverse=Component.UNDEFINED, loading_state=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'className', 'items', 'key', 'loading_state', 'mode', 'pending', 'pendingDot', 'reverse', 'style']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'className', 'items', 'key', 'loading_state', 'mode', 'pending', 'pendingDot', 'reverse', 'style']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        for k in ['items']:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')

        super(AntdTimeline, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AntdPopconfirm(Component):
    """An AntdPopconfirm component.


Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    The content of the tab - will only be displayed if this tab is
    selected.

- id (string; optional)

- cancelButtonProps (dict; optional)

- cancelCounts (number; default 0)

- cancelText (string; optional)

- className (string; optional)

- confirmCounts (number; default 0)

- disabled (boolean; optional)

- key (string; optional)

- loading_state (dict; optional)

    `loading_state` is a dict with keys:

    - component_name (string; optional):
        Holds the name of the component that is loading.

    - is_loading (boolean; optional):
        Determines if the component is loading or not.

    - prop_name (string; optional):
        Holds which property is loading.

- locale (a value equal to: 'zh-cn', 'en-us'; default 'zh-cn')

- mouseEnterDelay (number; optional)

- mouseLeaveDelay (number; optional)

- okButtonProps (dict; optional)

- okText (string; optional)

- overlayInnerStyle (dict; optional)

- overlayStyle (dict; optional)

- placement (a value equal to: 'top', 'left', 'right', 'bottom', 'topLeft', 'topRight', 'bottomLeft', 'bottomRight', 'leftTop', 'leftBottom', 'rightTop', 'rightBottom'; optional)

- popupContainer (a value equal to: 'parent', 'body'; default 'body')

- style (dict; optional)

- title (a list of or a singular dash component, string or number; optional)

- trigger (a value equal to: 'hover', 'focus', 'click' | list of a value equal to: 'hover', 'focus', 'click's; optional)"""
    _children_props = ['title']
    _base_nodes = ['title', 'children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdPopconfirm'
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, className=Component.UNDEFINED, style=Component.UNDEFINED, key=Component.UNDEFINED, locale=Component.UNDEFINED, title=Component.UNDEFINED, disabled=Component.UNDEFINED, placement=Component.UNDEFINED, mouseEnterDelay=Component.UNDEFINED, mouseLeaveDelay=Component.UNDEFINED, overlayStyle=Component.UNDEFINED, overlayInnerStyle=Component.UNDEFINED, okText=Component.UNDEFINED, okButtonProps=Component.UNDEFINED, cancelText=Component.UNDEFINED, cancelButtonProps=Component.UNDEFINED, confirmCounts=Component.UNDEFINED, cancelCounts=Component.UNDEFINED, popupContainer=Component.UNDEFINED, trigger=Component.UNDEFINED, loading_state=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'cancelButtonProps', 'cancelCounts', 'cancelText', 'className', 'confirmCounts', 'disabled', 'key', 'loading_state', 'locale', 'mouseEnterDelay', 'mouseLeaveDelay', 'okButtonProps', 'okText', 'overlayInnerStyle', 'overlayStyle', 'placement', 'popupContainer', 'style', 'title', 'trigger']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'cancelButtonProps', 'cancelCounts', 'cancelText', 'className', 'confirmCounts', 'disabled', 'key', 'loading_state', 'locale', 'mouseEnterDelay', 'mouseLeaveDelay', 'okButtonProps', 'okText', 'overlayInnerStyle', 'overlayStyle', 'placement', 'popupContainer', 'style', 'title', 'trigger']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AntdPopconfirm, self).__init__(children=children, **args)



from .AntdAccordion import AntdAccordion
from .AntdAffix import AntdAffix
from .AntdAlert import AntdAlert
from .AntdAnchor import AntdAnchor
from .AntdAvatar import AntdAvatar
from .AntdAvatarGroup import AntdAvatarGroup
from .AntdBackTop import AntdBackTop
from .AntdBadge import AntdBadge
from .AntdBreadcrumb import AntdBreadcrumb
from .AntdButton import AntdButton
from .AntdCalendar import AntdCalendar
from .AntdCarousel import AntdCarousel
from .AntdCascader import AntdCascader
from .AntdCheckbox import AntdCheckbox
from .AntdCheckboxGroup import AntdCheckboxGroup
from .AntdCollapse import AntdCollapse
from .AntdComment import AntdComment
from .AntdConfigProvider import AntdConfigProvider
from .AntdCopyText import AntdCopyText
from .AntdCountdown import AntdCountdown
from .AntdDatePicker import AntdDatePicker
from .AntdDateRangePicker import AntdDateRangePicker
from .AntdDivider import AntdDivider
from .AntdDrawer import AntdDrawer
from .AntdDropdown import AntdDropdown
from .AntdEmpty import AntdEmpty
from .AntdIcon import AntdIcon
from .AntdImage import AntdImage
from .AntdInput import AntdInput
from .AntdInputNumber import AntdInputNumber
from .AntdMentions import AntdMentions
from .AntdMenu import AntdMenu
from .AntdMessage import AntdMessage
from .AntdModal import AntdModal
from .AntdNotification import AntdNotification
from .AntdPageHeader import AntdPageHeader
from .AntdPagination import AntdPagination
from .AntdPopconfirm import AntdPopconfirm
from .AntdPopover import AntdPopover
from .AntdPopupCard import AntdPopupCard
from .AntdProgress import AntdProgress
from .AntdRadioGroup import AntdRadioGroup
from .AntdRate import AntdRate
from .AntdResult import AntdResult
from .AntdRibbon import AntdRibbon
from .AntdSegmented import AntdSegmented
from .AntdSegmentedColoring import AntdSegmentedColoring
from .AntdSelect import AntdSelect
from .AntdSlider import AntdSlider
from .AntdSpace import AntdSpace
from .AntdSpin import AntdSpin
from .AntdSpoiler import AntdSpoiler
from .AntdStatistic import AntdStatistic
from .AntdSteps import AntdSteps
from .AntdSwitch import AntdSwitch
from .AntdTable import AntdTable
from .AntdTag import AntdTag
from .AntdTimeline import AntdTimeline
from .AntdTimePicker import AntdTimePicker
from .AntdTimeRangePicker import AntdTimeRangePicker
from .AntdTooltip import AntdTooltip
from .AntdTransfer import AntdTransfer
from .AntdTree import AntdTree
from .AntdTreeSelect import AntdTreeSelect
from .AntdWatermark import AntdWatermark
from .AntdCard import AntdCard
from .AntdCardGrid import AntdCardGrid
from .AntdCheckCard import AntdCheckCard
from .AntdCheckCardGroup import AntdCheckCardGroup
from .AntdDescriptionItem import AntdDescriptionItem
from .AntdDescriptions import AntdDescriptions
from .AntdForm import AntdForm
from .AntdFormItem import AntdFormItem
from .AntdCol import AntdCol
from .AntdRow import AntdRow
from .AntdContent import AntdContent
from .AntdFooter import AntdFooter
from .AntdHeader import AntdHeader
from .AntdLayout import AntdLayout
from .AntdSider import AntdSider
from .AntdCustomSkeleton import AntdCustomSkeleton
from .AntdSkeleton import AntdSkeleton
from .AntdSkeletonAvatar import AntdSkeletonAvatar
from .AntdSkeletonButton import AntdSkeletonButton
from .AntdSkeletonImage import AntdSkeletonImage
from .AntdSkeletonInput import AntdSkeletonInput
from .AntdTabPane import AntdTabPane
from .AntdTabs import AntdTabs
from .AntdParagraph import AntdParagraph
from .AntdText import AntdText
from .AntdTitle import AntdTitle
from .AntdDraggerUpload import AntdDraggerUpload
from .AntdPictureUpload import AntdPictureUpload
from .AntdUpload import AntdUpload

__all__ = [
    "AntdAccordion",
    "AntdAffix",
    "AntdAlert",
    "AntdAnchor",
    "AntdAvatar",
    "AntdAvatarGroup",
    "AntdBackTop",
    "AntdBadge",
    "AntdBreadcrumb",
    "AntdButton",
    "AntdCalendar",
    "AntdCarousel",
    "AntdCascader",
    "AntdCheckbox",
    "AntdCheckboxGroup",
    "AntdCollapse",
    "AntdComment",
    "AntdConfigProvider",
    "AntdCopyText",
    "AntdCountdown",
    "AntdDatePicker",
    "AntdDateRangePicker",
    "AntdDivider",
    "AntdDrawer",
    "AntdDropdown",
    "AntdEmpty",
    "AntdIcon",
    "AntdImage",
    "AntdInput",
    "AntdInputNumber",
    "AntdMentions",
    "AntdMenu",
    "AntdMessage",
    "AntdModal",
    "AntdNotification",
    "AntdPageHeader",
    "AntdPagination",
    "AntdPopconfirm",
    "AntdPopover",
    "AntdPopupCard",
    "AntdProgress",
    "AntdRadioGroup",
    "AntdRate",
    "AntdResult",
    "AntdRibbon",
    "AntdSegmented",
    "AntdSegmentedColoring",
    "AntdSelect",
    "AntdSlider",
    "AntdSpace",
    "AntdSpin",
    "AntdSpoiler",
    "AntdStatistic",
    "AntdSteps",
    "AntdSwitch",
    "AntdTable",
    "AntdTag",
    "AntdTimeline",
    "AntdTimePicker",
    "AntdTimeRangePicker",
    "AntdTooltip",
    "AntdTransfer",
    "AntdTree",
    "AntdTreeSelect",
    "AntdWatermark",
    "AntdCard",
    "AntdCardGrid",
    "AntdCheckCard",
    "AntdCheckCardGroup",
    "AntdDescriptionItem",
    "AntdDescriptions",
    "AntdForm",
    "AntdFormItem",
    "AntdCol",
    "AntdRow",
    "AntdContent",
    "AntdFooter",
    "AntdHeader",
    "AntdLayout",
    "AntdSider",
    "AntdCustomSkeleton",
    "AntdSkeleton",
    "AntdSkeletonAvatar",
    "AntdSkeletonButton",
    "AntdSkeletonImage",
    "AntdSkeletonInput",
    "AntdTabPane",
    "AntdTabs",
    "AntdParagraph",
    "AntdText",
    "AntdTitle",
    "AntdDraggerUpload",
    "AntdPictureUpload",
    "AntdUpload"
]


# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AntdComment(Component):
    """An AntdComment component.


Keyword arguments:

- children (a list of or a singular dash component, string or number; optional)

- id (string; optional)

- action (a value equal to: 'liked', 'disliked', 'default'; optional)

- authorName (string; optional)

- authorNameHref (string; optional)

- avatarProps (dict; optional)

- className (string | dict; optional)

- commentContent (a list of or a singular dash component, string or number; optional)

- commentId (string; optional)

- defaultAction (a value equal to: 'liked', 'disliked', 'default'; optional)

- deleteClicks (number; default 0)

- dislikesCount (number; default 0)

- fromNow (boolean; default False)

- likesCount (number; default 0)

- loading_state (dict; optional)

    `loading_state` is a dict with keys:

    - component_name (string; optional):
        Holds the name of the component that is loading.

    - is_loading (boolean; optional):
        Determines if the component is loading or not.

    - prop_name (string; optional):
        Holds which property is loading.

- locale (a value equal to: 'zh-cn', 'en-us'; default 'zh-cn')

- popupContainer (a value equal to: 'parent', 'body'; default 'body')

- publishTime (dict; required)

    `publishTime` is a dict with keys:

    - format (string; optional)

    - value (string; required)

- replyClicks (number; default 0)

- showDelete (boolean; default False)

- showLikeDislike (boolean; default True)

- showReply (boolean; default True)

- style (dict; optional)"""
    _children_props = ['commentContent']
    _base_nodes = ['commentContent', 'children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdComment'
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, className=Component.UNDEFINED, style=Component.UNDEFINED, locale=Component.UNDEFINED, commentId=Component.UNDEFINED, authorName=Component.UNDEFINED, authorNameHref=Component.UNDEFINED, publishTime=Component.REQUIRED, fromNow=Component.UNDEFINED, showLikeDislike=Component.UNDEFINED, showReply=Component.UNDEFINED, showDelete=Component.UNDEFINED, replyClicks=Component.UNDEFINED, deleteClicks=Component.UNDEFINED, commentContent=Component.UNDEFINED, likesCount=Component.UNDEFINED, dislikesCount=Component.UNDEFINED, action=Component.UNDEFINED, defaultAction=Component.UNDEFINED, avatarProps=Component.UNDEFINED, popupContainer=Component.UNDEFINED, loading_state=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'action', 'authorName', 'authorNameHref', 'avatarProps', 'className', 'commentContent', 'commentId', 'defaultAction', 'deleteClicks', 'dislikesCount', 'fromNow', 'likesCount', 'loading_state', 'locale', 'popupContainer', 'publishTime', 'replyClicks', 'showDelete', 'showLikeDislike', 'showReply', 'style']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'action', 'authorName', 'authorNameHref', 'avatarProps', 'className', 'commentContent', 'commentId', 'defaultAction', 'deleteClicks', 'dislikesCount', 'fromNow', 'likesCount', 'loading_state', 'locale', 'popupContainer', 'publishTime', 'replyClicks', 'showDelete', 'showLikeDislike', 'showReply', 'style']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        for k in ['publishTime']:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')

        super(AntdComment, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AntdButton(Component):
    """An AntdButton component.


Keyword arguments:

- children (a list of or a singular dash component, string or number; optional)

- id (string; optional)

- autoSpin (boolean; default False)

- block (boolean; default False)

- className (string | dict; optional)

- danger (boolean; default False)

- debounceWait (number; default 200)

- disabled (boolean; default False)

- href (string; optional)

- icon (a list of or a singular dash component, string or number; optional)

- key (string; optional)

- loading (boolean; optional)

- loadingChildren (a list of or a singular dash component, string or number; optional)

- loading_state (dict; optional)

    `loading_state` is a dict with keys:

    - component_name (string; optional):
        Holds the name of the component that is loading.

    - is_loading (boolean; optional):
        Determines if the component is loading or not.

    - prop_name (string; optional):
        Holds which property is loading.

- nClicks (number; default 0)

- shape (a value equal to: 'circle', 'round'; optional)

- size (a value equal to: 'small', 'middle', 'large'; optional)

- style (dict; optional)

- target (string; optional)

- type (a value equal to: 'primary', 'ghost', 'dashed', 'link', 'text', 'default'; default 'default')"""
    _children_props = ['loadingChildren', 'icon']
    _base_nodes = ['loadingChildren', 'icon', 'children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdButton'
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, loadingChildren=Component.UNDEFINED, className=Component.UNDEFINED, style=Component.UNDEFINED, key=Component.UNDEFINED, type=Component.UNDEFINED, href=Component.UNDEFINED, target=Component.UNDEFINED, block=Component.UNDEFINED, danger=Component.UNDEFINED, disabled=Component.UNDEFINED, shape=Component.UNDEFINED, size=Component.UNDEFINED, nClicks=Component.UNDEFINED, debounceWait=Component.UNDEFINED, icon=Component.UNDEFINED, loading=Component.UNDEFINED, autoSpin=Component.UNDEFINED, loading_state=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'autoSpin', 'block', 'className', 'danger', 'debounceWait', 'disabled', 'href', 'icon', 'key', 'loading', 'loadingChildren', 'loading_state', 'nClicks', 'shape', 'size', 'style', 'target', 'type']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'autoSpin', 'block', 'className', 'danger', 'debounceWait', 'disabled', 'href', 'icon', 'key', 'loading', 'loadingChildren', 'loading_state', 'nClicks', 'shape', 'size', 'style', 'target', 'type']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AntdButton, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AntdTransfer(Component):
    """An AntdTransfer component.


Keyword arguments:

- id (string; optional)

- className (string | dict; optional)

- dataSource (list of dicts; optional)

    `dataSource` is a list of dicts with keys:

    - key (string | number; optional)

    - title (a list of or a singular dash component, string or number; optional)

- disabled (boolean; default False)

- height (string; optional)

- key (string; optional)

- loading_state (dict; optional)

    `loading_state` is a dict with keys:

    - component_name (string; optional):
        Holds the name of the component that is loading.

    - is_loading (boolean; optional):
        Determines if the component is loading or not.

    - prop_name (string; optional):
        Holds which property is loading.

- locale (a value equal to: 'zh-cn', 'en-us'; default 'zh-cn')

- moveDirection (a value equal to: 'left', 'right'; optional)

- moveKeys (list of number | strings; optional)

- operations (list of strings; default ['', ''])

- pagination (dict; default False)

    `pagination` is a boolean | dict with keys:

    - pageSize (number; optional)

- persisted_props (list of a value equal to: 'targetKeys's; default ['targetKeys']):
    Properties whose user interactions will persist after refreshing
    the  component or the page. Since only `value` is allowed this
    prop can  normally be ignored.

- persistence (boolean | string | number; optional):
    Used to allow user interactions in this component to be persisted
    when  the component - or the page - is refreshed. If `persisted`
    is truthy and  hasn't changed from its previous value, a `value`
    that the user has  changed while using the app will keep that
    change, as long as  the new `value` also matches what was given
    originally.  Used in conjunction with `persistence_type`.

- persistence_type (a value equal to: 'local', 'session', 'memory'; default 'local'):
    Where persisted user changes will be stored:  memory: only kept in
    memory, reset on page refresh.  local: window.localStorage, data
    is kept after the browser quit.  session: window.sessionStorage,
    data is cleared once the browser quit.

- showSearch (boolean; default False)

- showSelectAll (boolean; default True)

- status (a value equal to: 'error', 'warning'; optional)

- style (dict; optional)

- targetKeys (list of number | strings; optional)

- titles (list of a list of or a singular dash component, string or numbers; optional)"""
    _children_props = ['dataSource[].title', 'titles']
    _base_nodes = ['titles', 'children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdTransfer'
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, className=Component.UNDEFINED, style=Component.UNDEFINED, key=Component.UNDEFINED, locale=Component.UNDEFINED, dataSource=Component.UNDEFINED, height=Component.UNDEFINED, pagination=Component.UNDEFINED, operations=Component.UNDEFINED, showSearch=Component.UNDEFINED, showSelectAll=Component.UNDEFINED, titles=Component.UNDEFINED, targetKeys=Component.UNDEFINED, moveDirection=Component.UNDEFINED, moveKeys=Component.UNDEFINED, disabled=Component.UNDEFINED, status=Component.UNDEFINED, loading_state=Component.UNDEFINED, persistence=Component.UNDEFINED, persisted_props=Component.UNDEFINED, persistence_type=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'className', 'dataSource', 'disabled', 'height', 'key', 'loading_state', 'locale', 'moveDirection', 'moveKeys', 'operations', 'pagination', 'persisted_props', 'persistence', 'persistence_type', 'showSearch', 'showSelectAll', 'status', 'style', 'targetKeys', 'titles']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'className', 'dataSource', 'disabled', 'height', 'key', 'loading_state', 'locale', 'moveDirection', 'moveKeys', 'operations', 'pagination', 'persisted_props', 'persistence', 'persistence_type', 'showSearch', 'showSelectAll', 'status', 'style', 'targetKeys', 'titles']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(AntdTransfer, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AntdSpoiler(Component):
    """An AntdSpoiler component.


Keyword arguments:

- children (a list of or a singular dash component, string or number; optional)

- id (string; optional)

- className (string | dict; optional)

- contentClassName (string; optional)

- contentStyle (dict; optional)

- hideLabel (a list of or a singular dash component, string or number; optional)

- key (string; optional)

- labelPosition (a value equal to: 'left', 'right'; default 'left')

- loading_state (dict; optional)

    `loading_state` is a dict with keys:

    - component_name (string; optional):
        Holds the name of the component that is loading.

    - is_loading (boolean; optional):
        Determines if the component is loading or not.

    - prop_name (string; optional):
        Holds which property is loading.

- locale (a value equal to: 'zh-cn', 'en-us'; default 'zh-cn')

- maxHeight (number; default 50)

- open (boolean; default False)

- showLabel (a list of or a singular dash component, string or number; optional)

- style (dict; optional)

- transitionDuration (number; default 0.1)"""
    _children_props = ['hideLabel', 'showLabel']
    _base_nodes = ['hideLabel', 'showLabel', 'children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdSpoiler'
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, className=Component.UNDEFINED, style=Component.UNDEFINED, contentClassName=Component.UNDEFINED, contentStyle=Component.UNDEFINED, key=Component.UNDEFINED, locale=Component.UNDEFINED, hideLabel=Component.UNDEFINED, showLabel=Component.UNDEFINED, labelPosition=Component.UNDEFINED, open=Component.UNDEFINED, maxHeight=Component.UNDEFINED, transitionDuration=Component.UNDEFINED, loading_state=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'className', 'contentClassName', 'contentStyle', 'hideLabel', 'key', 'labelPosition', 'loading_state', 'locale', 'maxHeight', 'open', 'showLabel', 'style', 'transitionDuration']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'className', 'contentClassName', 'contentStyle', 'hideLabel', 'key', 'labelPosition', 'loading_state', 'locale', 'maxHeight', 'open', 'showLabel', 'style', 'transitionDuration']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AntdSpoiler, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AntdAccordion(Component):
    """An AntdAccordion component.


Keyword arguments:

- children (a list of or a singular dash component, string or number; optional)

- id (string; optional)

- accordion (boolean; default True)

- activeKey (string | list of strings | number | list of numbers; optional)

- bordered (boolean; default True)

- className (string | dict; optional)

- collapsible (a value equal to: 'header', 'disabled'; optional)

- defaultActiveKey (string | list of strings | number | list of numbers; optional)

- expandIconPosition (a value equal to: 'left', 'right'; default 'left')

- ghost (boolean; default False)

- items (list of dicts; optional)

    `items` is a list of dicts with keys:

    - children (a list of or a singular dash component, string or number; optional)

    - className (string; optional)

    - collapsible (a value equal to: 'header', 'disabled'; optional)

    - extra (a list of or a singular dash component, string or number; optional)

    - forceRender (boolean; optional)

    - key (string | number; required)

    - showArrow (boolean; optional)

    - style (dict; optional)

    - title (a list of or a singular dash component, string or number; optional)

- key (string; optional)

- loading_state (dict; optional)

    `loading_state` is a dict with keys:

    - component_name (string; optional):
        Holds the name of the component that is loading.

    - is_loading (boolean; optional):
        Determines if the component is loading or not.

    - prop_name (string; optional):
        Holds which property is loading.

- style (dict; optional)"""
    _children_props = ['items[].children', 'items[].title', 'items[].extra']
    _base_nodes = ['children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdAccordion'
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, className=Component.UNDEFINED, style=Component.UNDEFINED, key=Component.UNDEFINED, items=Component.UNDEFINED, accordion=Component.UNDEFINED, activeKey=Component.UNDEFINED, defaultActiveKey=Component.UNDEFINED, bordered=Component.UNDEFINED, collapsible=Component.UNDEFINED, expandIconPosition=Component.UNDEFINED, ghost=Component.UNDEFINED, loading_state=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'accordion', 'activeKey', 'bordered', 'className', 'collapsible', 'defaultActiveKey', 'expandIconPosition', 'ghost', 'items', 'key', 'loading_state', 'style']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'accordion', 'activeKey', 'bordered', 'className', 'collapsible', 'defaultActiveKey', 'expandIconPosition', 'ghost', 'items', 'key', 'loading_state', 'style']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AntdAccordion, self).__init__(children=children, **args)
